exceptiontools.LineBreakError
=============================

.. inheritance-diagram:: abjad.tools.exceptiontools.LineBreakError.LineBreakError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.LineBreakError.LineBreakError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.LineBreakError.LineBreakError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.LineBreakError.LineBreakError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.LineBreakError.LineBreakError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.LineBreakError.LineBreakError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.LineBreakError.LineBreakError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.LineBreakError.LineBreakError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.LineBreakError.LineBreakError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.LineBreakError.LineBreakError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
